==> wpewebkit_2.48.3.orig.tar.xz: wpewebkit-2.48.3/Source/WebCore/html/parser/HTMLEntityTable.h <==
/**
 * Copyright (C) 2010-2014 Google, Inc. All Rights Reserved.
 * Copyright (C) 2023 Apple, Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#include <unicode/umachine.h>

namespace WebCore {

// Optimize packing since there are over 2000 of these.
struct HTMLEntityTableEntry {
    const char* nameCharacters() const;
    unsigned nameLength() const { return nameLengthExcludingSemicolon + nameIncludesTrailingSemicolon; }

    unsigned firstCharacter : 21; // All Unicode characters fit in 21 bits.
    unsigned optionalSecondCharacter : 16; // Two-character sequences are all BMP characters.
    unsigned nameCharactersOffset : 14;
    unsigned nameLengthExcludingSemicolon : 5;
    unsigned nameIncludesTrailingSemicolon : 1;
};

class HTMLEntityTable {
public:
    static const HTMLEntityTableEntry* firstEntry();
    static const HTMLEntityTableEntry* lastEntry();

    static const HTMLEntityTableEntry* firstEntryStartingWith(UChar);
    static const HTMLEntityTableEntry* lastEntryStartingWith(UChar);
};

} // namespace WebCore

==> wpewebkit_2.50.5.orig.tar.xz: wpewebkit-2.50.5/Source/WebCore/html/parser/HTMLEntityTable.h <==
/**
 * Copyright (C) 2010-2014 Google, Inc. All rights reserved.
 * Copyright (C) 2023 Apple, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#include <unicode/umachine.h>

namespace WebCore {

// Optimize packing since there are over 2000 of these.
struct HTMLEntityTableEntry {
    std::span<const char> nameCharacters() const;
    unsigned nameLength() const { return nameLengthExcludingSemicolon + nameIncludesTrailingSemicolon; }

    unsigned firstCharacter : 21; // All Unicode characters fit in 21 bits.
    unsigned optionalSecondCharacter : 16; // Two-character sequences are all BMP characters.
    unsigned nameCharactersOffset : 14;
    unsigned nameLengthExcludingSemicolon : 5;
    unsigned nameIncludesTrailingSemicolon : 1;
};

class HTMLEntityTable {
public:
    static std::span<const HTMLEntityTableEntry> entries();
    static std::span<const HTMLEntityTableEntry> entriesStartingWith(char16_t);
};

} // namespace WebCore
